@@ -7,7 +7,7 @@
 #define make_char(x) x ? Rf_mkChar(x) : NA_STRING
 #define ALT(x,y) (x != NULL ? x : y)
 
-gpgme_ctx_t ctx;
+extern gpgme_ctx_t ctx;
 gpgme_error_t pwprompt(void *hook, const char *uid_hint, const char *passphrase_info, int prev_was_bad, int fd);
 SEXP data_to_string(gpgme_data_t buf);
 SEXP data_to_raw(gpgme_data_t buf);
